@@ -51,7 +51,9 @@ def make_a_zip_file(dirpath: pl.Path) -> pl.Path:
 
 def make_sure_theres_a_nested_folder_and_index_html(dirpath: pl.Path) -> None:
     if "folder" not in [d.name for d in list(dirpath.iterdir())]:
-        raise NoNestedFolder
+        raise NoNestedFolder(
+            "Please create a folder in the root of the site's directory, and put all the files in there."
+        )
 
     if "index.html" not in [i.name for i in list((dirpath / "folder").iterdir())]:
         raise NoIndexHtml
@@ -76,7 +78,7 @@ def deploy_page_to_netlify(dirpath: pl.Path, custom_domain: str | None = None) -
     rj = response.json()
     print("the site is published: " + rj["url"])
     if custom_domain is not None:
-        sleep(2)
+        check_that_custom_domain_is_not_in_use(custom_domain)
         set_to_custom_domain(rj["id"], custom_domain)
 
 
@@ -132,7 +134,6 @@ def check_that_custom_domain_is_not_in_use(custom_domain: str) -> None:
 
 def set_to_custom_domain(site_id: str, custom_domain: str) -> None:
     URL = f"https://app.netlify.com/access-control/bb-api/api/v1/sites/{site_id}"
-    check_that_custom_domain_is_not_in_use(custom_domain)
     response = requests.put(
         URL,
         json={"custom_domain": custom_domain},
@@ -172,6 +173,7 @@ def cli_set_custom_domain() -> None:
     except IndexError:
         print("Please provide a --custom-domain")
         return
+    check_that_custom_domain_is_not_in_use(custom_domain)
     try:
         domain = sys.argv[sys.argv.index("--domain") + 1]
     except IndexError:
@@ -233,12 +235,12 @@ def delete_site(site_id: str) -> None:
 def display_help() -> None:
     print(
         """Usage:
-    netlify.py --help
-    netlify.py --root-dir <path> --custom-domain <domain (or subdomain prefix if there's only one domain in NETLIFY_DOMAINS)>
-    netlify.py --list-sites
-    netlify.py --custom-domain <custom_domain (or subdomain prefix if there's only one domain in NETLIFY_DOMAINS)> --domain <existing_domain>
-    netlify.py --remove-custom-domain <custom_domain (or subdomain prefix if there's only one domain in NETLIFY_DOMAINS)>
-    netlify.py --delete-site <domain (or subdomain prefix if there's only one domain in NETLIFY_DOMAINS)>
+    pub --help
+    pub --root-dir <path> --custom-domain <domain (or subdomain prefix if there's only one domain in NETLIFY_DOMAINS)>
+    pub --list-sites
+    pub --custom-domain <custom_domain (or subdomain prefix if there's only one domain in NETLIFY_DOMAINS)> --domain <existing_domain>
+    pub --remove-custom-domain <custom_domain (or subdomain prefix if there's only one domain in NETLIFY_DOMAINS)>
+    pub --delete-site <domain (or subdomain prefix if there's only one domain in NETLIFY_DOMAINS)>
     """
     )
 
@@ -306,12 +308,10 @@ def cli_list_sites() -> None:
 
 
 def main() -> None:
-    if "--help" in sys.argv:
-        display_help()
-        sys.exit()
+    if "--help" in sys.argv or len(sys.argv) == 1:
+        return display_help()
     elif "--list-sites" in sys.argv:
-        cli_list_sites()
-        sys.exit()
+        return cli_list_sites()
     elif "--remove-custom-domain" in sys.argv:
         try:
             cli_remove_custom_domain()
@@ -319,30 +319,29 @@ def main() -> None:
             print("No site found with that custom domain")
         except NoCustomDomains:
             print("No custom domains configured in NETLIFY_DOMAINS")
-        sys.exit()
+        return
     elif "--delete-site" in sys.argv or "--remove-site" in sys.argv:
         try:
             cli_delete_site()
         except NoCustomDomains as e:
             print(str(e))
-        sys.exit()
+        return
     elif "--custom-domain" in sys.argv and "--root-dir" not in sys.argv:
         if len(NETLIFY_DOMAINS) == 0:
             print("No custom domains configured in NETLIFY_DOMAINS")
-            sys.exit()
-        if "--domain" in sys.argv:
+            return
+        if "--domain" not in sys.argv:
             print("Please supply a --domain")
-            sys.exit()
+            return
         try:
             cli_set_custom_domain()
         except DomainInUse:
             print("That domain is already in use")
-            sys.exit()
-        sys.exit()
+        return
     else:
         try:
             deploy_site()
-        except (NoCustomDomains, DomainInUse) as e:
+        except (NoCustomDomains, DomainInUse, NoNestedFolder) as e:
             print(str(e))
 
 
